.. _model documentation:

=====
Model
=====

The following section explains the inputs dataset and the MATER model framework with 2 different reading levels. 
Low level being the more detailed documentation.

.. toctree::
    :maxdepth: 3

    input
    high_level
    low_level